@@ -48,7 +48,24 @@ def command_clone(git, gitproject, project, clargs):
     return gitdir
 
 class ClonePlugin(Plugin):
-    """A plugin to implement the clone command."""
+    """
+    The clone command clones a repository.
+
+    Summary:
+
+      git <project> clone <url> [<path>] [--bare]
+
+    By itself clone has just the very basic funcionality of the built-in git
+    clone command.  Plugins may add options to give the clone command more
+    features.  For example, the woktree command adds a --worktree option to have
+    clone create a ``worktree layout.''
+
+    See also:
+
+      worktree
+
+    """
+
     def __init__(self):
         super().__init__('clone')
 
